@@ -50,9 +50,9 @@ def validate_dict(rule, value):
     unknown = data_keys - spec_keys
     #missing = spec_keys - data_keys
 
-    if unknown and not rule.dict_skip_unknown_keys:
-        raise errors.UnknownKey('Unknown keys: {0}'.format(
-            ', '.join(compat.safe_str(x) for x in unknown)))
+    if unknown and not rule.dict_allow_unknown_keys:
+        raise errors.UnknownKey('"{0}"'.format(
+            '", "'.join(compat.safe_str(x) for x in unknown)))
 
     for key in spec_keys | data_keys:
         subrule = canonize(rule.inner_spec.get(key))
@@ -122,7 +122,8 @@ def validate(rule, value):
     Always returns ``None``.
 
     :rule:
-        a :class:`~monk.schema.Rule` instance.
+        a :class:`~monk.schema.Rule` instance or any other value digestible
+        by :func:`canonize`.
     :value:
         any value including complex structures.
 
@@ -169,3 +170,6 @@ def validate(rule, value):
         assert not rule.inner_spec
         if isinstance(rule.datatype, type):
             validate_type(rule, value)
+
+    for validator in rule.validators:
+        validator(value)
